@@ -37,11 +37,11 @@ App::GitHooks - Extensible plugins system for git hooks.
 
 =head1 VERSION
 
-Version 1.8.0
+Version 1.9.0
 
 =cut
 
-our $VERSION = '1.8.0';
+our $VERSION = '1.9.0';
 
 
 =head1 DESCRIPTION
@@ -362,6 +362,12 @@ they will be ignored.
 
 	force_plugins = App::GitHooks::Plugin::ValidatePODFormat, App::GitHooks::Plugin::RequireCommitMessage
 
+=item * min_app_githooks_version
+
+Specify the minimum version of App::GitHooks.
+
+	min_app_githooks_version = 1.9.0
+
 =back
 
 
@@ -397,6 +403,33 @@ failed.
 =back
 
 
+=head1 ENVIRONMENT VARIABLES
+
+=head2 GITHOOKS_SKIP
+
+Comma separated list of hooks to skip. A warning is issued for each hook that
+would otherwise be triggered.
+
+	GITHOOKS_SKIP=pre-commit,update
+
+=head2 GITHOOKS_DISABLE
+
+Works similarly to C<GITHOOKS_SKIP>, but it skips all the possible hooks. Set
+it to a true value, e.g. 1.
+
+	GITHOOKS_DISABLE=1
+
+=head2 GITHOOKSRC
+
+Contains path to a custom configuration file, see "Configuration file
+locations" above.
+
+=head2 GITHOOKSRC_FORCE
+
+Similar to C<GITHOOKSRC> but with a higher priority. See "Configuration file
+locations" above.
+
+
 =head1 FUNCTIONS
 
 =head2 run()
@@ -452,6 +485,11 @@ sub run
 		croak "Invalid hook name $name"
 			if scalar( grep { $_ eq $name } @$HOOK_NAMES ) == 0;
 
+		if (my $env_var = _should_skip( $name )) {
+			carp "Hook $name skipped because of $env_var";
+			return $HOOK_EXIT_SUCCESS;
+		}
+
 		# Validate arguments.
 		croak 'Unknown argument(s): ' . join( ', ', keys %args )
 			if scalar( keys %args ) != 0;
@@ -806,6 +844,11 @@ sub get_config
 		);
 	}
 
+	# Enforce the specifying of min version of App::GitHooks
+	my $min_version = $self->{'config'}->get('_','min_app_githooks_version');
+	croak "Requires at least App::Githooks version $min_version, you have version $VERSION"
+		if $min_version && $min_version gt $VERSION;
+
 	return $self->{'config'};
 }
 
@@ -1126,6 +1169,30 @@ sub _to_camelcase
 }
 
 
+=head2 _should_skip()
+
+See the environment variables GITHOOKS_SKIP and GITHOOKS_DISABLE above. This
+function returns the variable name that would be the reason to skip the given
+hook, or nothing.
+
+	return if _should_skip( $name );
+
+=cut
+
+sub _should_skip
+{
+	my ( $name ) = @_;
+	return unless exists $ENV{'GITHOOKS_SKIP'}
+	           || exists $ENV{'GITHOOKS_DISABLE'};
+
+	return 'GITHOOKS_DISABLE' if $ENV{'GITHOOKS_DISABLE'};
+
+	my %skip;
+	@skip{ split /,/, $ENV{'GITHOOKS_SKIP'} } = ();
+	return exists $skip{ $name } && 'GITHOOKS_SKIP';
+}
+
+
 =head1 NOTES
 
 =head2 Manual installation
@@ -1201,7 +1268,7 @@ C<< <aubertg at cpan.org> >>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2013-2016 Guillaume Aubert.
+Copyright 2013-2017 Guillaume Aubert.
 
 This code is free software; you can redistribute it and/or modify it under the
 same terms as Perl 5 itself.
