@@ -24,11 +24,11 @@ App::GitHooks::Hook::CommitMsg - Handle the commit-msg hook.
 
 =head1 VERSION
 
-Version 1.8.0
+Version 1.9.0
 
 =cut
 
-our $VERSION = '1.8.0';
+our $VERSION = '1.9.0';
 
 
 =head1 METHODS
@@ -114,7 +114,7 @@ sub run
 		# otherwise finish and let git complete.
 		if ( $has_errors )
 		{
-			print "Press <Enter> to edit again the commit message or Ctrl-C to abort the commit.\n";
+			print "Press <Enter> to edit the commit message or Ctrl-C to abort the commit.\n";
 			if ( $app->get_terminal()->is_interactive() )
 			{
 				my $input = <STDIN>; ## no critic (InputOutput::ProhibitExplicitStdin)
@@ -190,7 +190,7 @@ C<< <aubertg at cpan.org> >>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2013-2016 Guillaume Aubert.
+Copyright 2013-2017 Guillaume Aubert.
 
 This code is free software; you can redistribute it and/or modify it under the
 same terms as Perl 5 itself.
